==> groupfolders-v19.1.5.tar.gz: groupfolders/l10n/zh_TW.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "您無法移除您自己的讀取權限。",
    "Team folders" : "團隊資料夾",
    "Admin configured folders shared with everyone in a team" : "管理員設定，與團隊中所有人共用的資料夾",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "管理員設定資料夾與團隊中的每個人共用。\n\n可以在管理設定中的「團隊資料夾」設定。\n\n建立資料夾後，管理員可讓一個或多個團隊存取資料夾，控制他們的寫入/分享權限，並為資料夾指定配額。\n自 Hub 10/Nextcloud 31 起，管理員必須是團隊的一員，才能指派團隊資料夾。",
    "Unset" : "取消設定",
    "Denied (Inherited permission)" : "拒絕（繼承權限）",
    "Allowed (Inherited permission)" : "允許（繼承權限）",
    "Denied" : "拒絕",
    "Allowed" : "允許",
    "Access denied" : "拒絕存取",
    "Access allowed" : "允許存取",
    "Inherit permission" : "繼承權限",
    "Deny" : "否",
    "Allow" : "允許",
    "Group" : "群組",
    "Team" : "團隊",
    "Team folder" : "團隊資料夾",
    "Read" : "讀取",
    "Write" : "寫入",
    "Create" : "建立",
    "Delete" : "刪除",
    "Share" : "分享",
    "You" : "您",
    "Remove access rule" : "移除存取規則",
    "Add advanced permission rule" : "加入進階權限規則",
    "Select a user or group" : "選擇一個使用者或群組",
    "Open Team folder" : "開啟團隊資料夾",
    "Permission denied. User does not have sufficient permissions." : "沒有權限。使用者權限不足。",
    "Unexpected status from server" : "來自伺服器的意外狀態",
    "List of Team folders." : "團隊資料夾清單",
    "No Team folders yet" : "尚無團隊資料夾",
    "Team folders will show up here" : "團隊資料夾將會在此顯示",
    "Add group" : "新增群組",
    "Default" : "預設",
    "Unlimited" : "無限制",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "您確定要刪除「{folderName}」和裡面所有的檔案嗎？此動作無法復原",
    "Delete \"{folderName}\"?" : "刪除「{folderName}」？",
    "Team folder admin delegation" : "團隊資料夾委派管理員",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Nextcloud 讓您可以將團隊資料夾的管理權限委託給非管理員使用者。",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "請在下方指定將被允許管理團隊資料夾並使用其 API/REST 的群組。",
    "They will have access to all Team folders." : "他們可以存取所有的團隊資料夾。",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "請在下方指定將僅被允許管理團隊資料夾並使用其 API/REST 的群組。",
    "They will only have access to Team folders for which they have advanced permissions." : "他們僅能存取他們擁有進階權限的團隊資料夾。",
    "Group or team" : "群組或團隊",
    "Sort by number of groups or teams that have access to this folder" : "按可存取此資料夾的群組或團隊數量排序",
    "Sort by number of groups that have access to this folder" : "按可存取此資料夾的群組數量排序",
    "Folder name" : "資料夾名稱",
    "Quota" : "容量限額",
    "Advanced Permissions" : "進階權限",
    "Pagination of team folders" : "團隊資料夾分頁",
    "Previous" : "上一步",
    "Next" : "下一步",
    "User" : "使用者",
    "Unknown" : "未知",
    "Users/groups that can manage" : "可以管理以下內容的使用者/群組",
    "None" : "無",
    "No other groups or teams available" : "沒有其他群組或團隊了",
    "No other groups available" : "沒有其他群組了",
    "{displayName} (team)" : "{displayName}（團隊）",
    "Add group or team" : "新增群組或團隊",
    "{size} used" : "已使用 {size}",
    "Other …" : "其他……",
    "You can not remove your own read permission." : "您無法移除自己的讀取權限。",
    "Group folders" : "群組資料夾",
    "Admin configured folders shared with everyone in a group" : "管理員設定資料夾與群組中的每個人共用",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "管理員設定資料夾與群組中的每個人共用。\n\n可以在管理設定中的「群組資料夾」設定。\n\n建立資料夾之後，管理員可以設定讓一或多個群組存取。控制其寫入／分享權限並指定該資料夾的限額。",
    "Group folder" : "群組資料夾",
    "Open group folder" : "開啟群組資料夾",
    "List of group folders." : "群組資料夾清單。",
    "No group folders yet" : "尚無群組資料夾",
    "Group folders will show up here" : "群組資料夾將會在此顯示",
    "Group folder admin delegation" : "群組資料夾委派管理員",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloud 讓您可以將群組資料夾的管理權限委託給非管理員使用者。",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "請在下方指定將被允許管理群組資料夾並使用其 API/REST 的群組。",
    "They will have access to all group folders." : "他們可以存取所有的群組資料夾。",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "請在下方指定將僅被允許管理群組資料夾並使用其 API/REST 的群組。",
    "They will only have access to group folders for which they have advanced permissions." : "他們僅能存取他們擁有進階權限的群組資料夾。",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "管理員設定，與團隊中所有人共用的資料夾。\n\n可以在管理設定中的「團隊資料夾」設定。\n\n建立資料夾之後，管理員可以設定讓一或多個團隊存取。控制其寫入／分享權限並指定該資料夾的限額。"
},
"nplurals=1; plural=0;");

==> groupfolders-v20.1.1.tar.gz: groupfolders/l10n/zh_TW.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "您無法移除您自己的讀取權限。",
    "Team folders" : "團隊資料夾",
    "Team Folders" : "團隊資料夾",
    "Shared folders managed by admins, accessible to designated teams with configurable permissions and quotas" : "由管理員管理的共享資料夾，可供指定團隊存取，並具備可設定的權限與配額設定",
    "Team Folders (formerly \"Group Folders\") allows administrators to create and manage shared folders that are accessible \n\t\t\tto selected teams within Nextcloud.\n\n\t\t\tAdmins can configure folders from the Team Folders section in the admin settings, where they can grant access to one \n\t\t\tor more teams, set custom permissions (such as read, write, and sharing rights), and assign storage quotas to each \n\t\t\tfolder.\n\n\t\t\tAs of Hub 10/Nextcloud 31, admins must be members of a team to assign it a Team Folder. The app supports advanced \n\t\t\tfeatures such as quota management, granular access control, and integration with Nextcloud’s trash and versioning \n\t\t\tsystems." : "團隊資料夾（原稱「群組資料夾」）允許管理員建立並管理共享資料夾，這些資料夾僅限於 Nextcloud 內選定的團隊成員存取。\n\n\t\t\t管理員可在管理設定中的「團隊資料夾」區段進行資料夾設定，在此處可授予一個或多個團隊存取權限、設定自訂權限（例如讀取、寫入及分享權限），並為每個資料夾指派儲存配額。\n\n\t\t\t自 Hub 10/Nextcloud 31 版本起，管理員必須成為團隊成員才能為其指派團隊資料夾。此應用程式支援進階功能，例如配額管理、詳細的存取控制，以及與 Nextcloud 垃圾桶與版本控制系統的整合。",
    "Unset" : "取消設定",
    "Denied (Inherited permission)" : "拒絕（繼承權限）",
    "Allowed (Inherited permission)" : "允許（繼承權限）",
    "Denied" : "拒絕",
    "Allowed" : "允許",
    "Access denied" : "拒絕存取",
    "Access allowed" : "允許存取",
    "Inherit permission" : "繼承權限",
    "Deny" : "否",
    "Allow" : "允許",
    "Group" : "群組",
    "Team" : "團隊",
    "Team folder" : "團隊資料夾",
    "Read" : "讀取",
    "Write" : "寫入",
    "Create" : "建立",
    "Delete" : "刪除",
    "Share" : "分享",
    "You" : "您",
    "Remove access rule" : "移除存取規則",
    "Add advanced permission rule" : "加入進階權限規則",
    "Select a user or group" : "選擇一個使用者或群組",
    "Open Team folder" : "開啟團隊資料夾",
    "Permission denied. User does not have sufficient permissions." : "沒有權限。使用者權限不足。",
    "Unexpected status from server" : "來自伺服器的意外狀態",
    "List of Team folders." : "團隊資料夾清單",
    "No Team folders yet" : "尚無團隊資料夾",
    "Team folders will show up here" : "團隊資料夾將會在此顯示",
    "Add group" : "新增群組",
    "Default" : "預設",
    "Unlimited" : "無限制",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "您確定要刪除「{folderName}」和裡面所有的檔案嗎？此動作無法復原",
    "Delete \"{folderName}\"?" : "刪除「{folderName}」？",
    "Team folder admin delegation" : "團隊資料夾委派管理員",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Nextcloud 讓您可以將團隊資料夾的管理權限委託給非管理員使用者。",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "請在下方指定將被允許管理團隊資料夾並使用其 API/REST 的群組。",
    "They will have access to all Team folders." : "他們可以存取所有的團隊資料夾。",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "請在下方指定將僅被允許管理團隊資料夾並使用其 API/REST 的群組。",
    "They will only have access to Team folders for which they have advanced permissions." : "他們僅能存取他們擁有進階權限的團隊資料夾。",
    "Group or team" : "群組或團隊",
    "Sort by number of groups or teams that have access to this folder" : "按可存取此資料夾的群組或團隊數量排序",
    "Sort by number of groups that have access to this folder" : "按可存取此資料夾的群組數量排序",
    "Folder name" : "資料夾名稱",
    "Quota" : "容量限額",
    "Advanced Permissions" : "進階權限",
    "Pagination of team folders" : "團隊資料夾分頁",
    "Previous" : "上一步",
    "Next" : "下一步",
    "User" : "使用者",
    "Unknown" : "未知",
    "Users/groups that can manage" : "可以管理以下內容的使用者/群組",
    "None" : "無",
    "No other groups or teams available" : "沒有其他群組或團隊了",
    "No other groups available" : "沒有其他群組了",
    "{displayName} (team)" : "{displayName}（團隊）",
    "Add group or team" : "新增群組或團隊",
    "{size} used" : "已使用 {size}",
    "Other …" : "其他……",
    "You can not remove your own read permission." : "您無法移除自己的讀取權限。",
    "Group folders" : "群組資料夾",
    "Admin configured folders shared with everyone in a group" : "管理員設定資料夾與群組中的每個人共用",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "管理員設定資料夾與群組中的每個人共用。\n\n可以在管理設定中的「群組資料夾」設定。\n\n建立資料夾之後，管理員可以設定讓一或多個群組存取。控制其寫入／分享權限並指定該資料夾的限額。",
    "Group folder" : "群組資料夾",
    "Open group folder" : "開啟群組資料夾",
    "List of group folders." : "群組資料夾清單。",
    "No group folders yet" : "尚無群組資料夾",
    "Group folders will show up here" : "群組資料夾將會在此顯示",
    "Group folder admin delegation" : "群組資料夾委派管理員",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloud 讓您可以將群組資料夾的管理權限委託給非管理員使用者。",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "請在下方指定將被允許管理群組資料夾並使用其 API/REST 的群組。",
    "They will have access to all group folders." : "他們可以存取所有的群組資料夾。",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "請在下方指定將僅被允許管理群組資料夾並使用其 API/REST 的群組。",
    "They will only have access to group folders for which they have advanced permissions." : "他們僅能存取他們擁有進階權限的群組資料夾。",
    "Admin configured folders shared with everyone in a team" : "管理員設定，與團隊中所有人共用的資料夾",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "管理員設定，與團隊中所有人共用的資料夾。\n\n可以在管理設定中的「團隊資料夾」設定。\n\n建立資料夾之後，管理員可以設定讓一或多個團隊存取。控制其寫入／分享權限並指定該資料夾的限額。",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "管理員設定資料夾與團隊中的每個人共用。\n\n可以在管理設定中的「團隊資料夾」設定。\n\n建立資料夾後，管理員可讓一個或多個團隊存取資料夾，控制他們的寫入/分享權限，並為資料夾指定配額。\n自 Hub 10/Nextcloud 31 起，管理員必須是團隊的一員，才能指派團隊資料夾。"
},
"nplurals=1; plural=0;");
